#include <QApplication>
#include <QLocale>
#include <QStandardPaths>
#include <QString>
#include <QStringList>
#include <QTranslator>
#include "mainwindow.hpp"

int main(int argc, char *argv[])
{
	QApplication app(argc, argv);

	QString appTrPath;
	QString libLogViewTrPath;

#if defined(QT_DEBUG)
    appTrPath = app.applicationDirPath() + "/";
#else
#if defined(Q_OS_WIN)
    appTrPath = app.applicationDirPath() + "/translations";
    libLogViewTrPath = appTrPath;
#elif defined(Q_OS_UNIX)
    appTrPath = QStandardPaths::locate(QStandardPaths::AppDataLocation, "i18n", QStandardPaths::LocateDirectory);
    libLogViewTrPath = appTrPath + "/../../ExtendedLogViewer/i18n";
#endif
#endif

	QTranslator appTranslator;
	QTranslator libTranslator;

	bool appTranslationInstalled = false;
	bool libTranslationInstalled = false;

#if defined(Q_OS_WIN)
	QTranslator baseTranslator;
	bool baseTranslationInstalled = false;
#endif

	const QStringList uiLanguages = QLocale::system().uiLanguages();
	for (const QString &locale : uiLanguages)
	{
		const QString localeName = QLocale(locale).name();

#if defined(Q_OS_WIN)
        libLogViewTrPath = appTrPath;
		if(!baseTranslationInstalled)
		{
			const QString baseName = "/qt_" + localeName;
            bool baseTranslationLoaded = baseTranslator.load(appTrPath + baseName);
			if(baseTranslationLoaded)
			{
				app.installTranslator(&baseTranslator);
				baseTranslationInstalled = true;
			}
		}
#endif

		if (!appTranslationInstalled)
		{
			const QString baseNameApp = "/ExifRename_" + localeName;
			bool appTranslationLoaded = appTranslator.load(appTrPath + baseNameApp);
			if (appTranslationLoaded)
			{
				app.installTranslator(&appTranslator);
				appTranslationInstalled = true;
			}
		}

		if (!libTranslationInstalled)
		{
			const QString baseNameLibLogView = "/ExtendedLogViewer_" + localeName;
			bool libTranslationLoaded = libTranslator.load(libLogViewTrPath + baseNameLibLogView);
			if (libTranslationLoaded)
			{
				app.installTranslator(&libTranslator);
				libTranslationInstalled = true;
			}

		}
	}

	MainWindow w;
	w.show();
	return app.exec();
}
