#include <ExtendedLog/TextLogWriter.hpp>
#include <QDir>
#include <QFileDialog>
#include <QThread>

#include "mainwindow.hpp"
#include "progresswindow.hpp"
#include "rename.hpp"
#include "ui_mainwindow.h"

namespace extLog = ExtendedLog;

MainWindow::MainWindow(QWidget *parent)
	: QMainWindow(parent),
	  ui(new Ui::MainWindow)
{
	ui->setupUi(this);
	rename = nullptr;
	thread = nullptr;
}

MainWindow::~MainWindow()
{
	delete ui;
}


void MainWindow::btnStartClick()
{
    logFilePath = ui->txtFolder->text();
    logFilePath += (logFilePath.endsWith("\\") || logFilePath.endsWith("/")) ? "Exif-Rename.log" : "/Exif-Rename.log";
    extLog::TextLogWriter *logWriter = new extLog::TextLogWriter(logFilePath);
	rename = new Rename(ui->txtFolder->text(),
						ui->spinMin->value(),
						ui->spinHr->value(),
						logWriter
					);

	thread = new QThread();
	if(checkDir(ui->txtFolder->text()))
	{
		progressWindow = new ProgressWindow(this);
		progressWindow->setAttribute(Qt::WA_DeleteOnClose);
		progressWindow->show();
		makeThread();
		startThread();
	}
}

void MainWindow::btnSearchClick()
{
	QFileDialog dialog(this);
	if (checkDir(ui->txtFolder->text())) { dialog.setDirectory(ui->txtFolder->text()); }
	dialog.setFileMode(QFileDialog::Directory);
	dialog.setOption(QFileDialog::ShowDirsOnly);
	dialog.setViewMode(QFileDialog::Detail);

	if (dialog.exec())
	{
		ui->txtFolder->setText(dialog.selectedFiles().first());
		ui->btnStart->setEnabled(true);
	}
}

void MainWindow::makeThread()
{
	rename->moveToThread(thread);
	connect(rename, &Rename::error, progressWindow, &ProgressWindow::showError);
	connect(rename, &Rename::progressChanged, progressWindow, &ProgressWindow::showProgress);
	connect(thread, &QThread::started, rename, &Rename::rename);
	connect(rename, &Rename::finished, thread, &QThread::quit);
    connect(rename, &Rename::finished, this, &MainWindow::makeFinish);
	connect(rename, &Rename::finished, rename, &Rename::deleteLater);
    connect(thread, &QThread::finished, thread, &QThread::deleteLater);
    connect(this, &MainWindow::finish, progressWindow, &ProgressWindow::showFinish);
}

void MainWindow::startThread()
{
	thread->start();
}

void MainWindow::progessWindowClosing()
{
	thread->quit();
	//clearControls();
}

void MainWindow::txtFolderEdited(QString text)
{
	ui->btnStart->setEnabled(checkDir(text));
}

bool MainWindow::checkDir(QString dir)
{
	return QDir(dir).exists();
}

void MainWindow::makeFinish()
{
	ui->txtFolder->clear();
	ui->spinHr->setValue(0);
	ui->spinMin->setValue(0);
	ui->btnStart->setEnabled(false);
    emit finish(logFilePath);
}
