#include <ExtendedLogViewer/ExtendedLogViewer.hpp>
#include <ExtendedLog/TextLogReader.hpp>
#include <QCloseEvent>
#include <QMessageBox>
#include <QString>
#include <QStringList>

#include "progresswindow.hpp"
#include "ui_progresswindow.h"


ProgressWindow::ProgressWindow(QWidget *parent) :
	QMainWindow(parent),
	ui(new Ui::ProgressWindow)
{
	ui->setupUi(this);
}

ProgressWindow::~ProgressWindow()
{
	delete ui;
}

void ProgressWindow::closeEvent(QCloseEvent *event)
{
	if (ui->progressBar->value() != 100 && !finish)
	{
		int closing = QMessageBox::question(
						  this,
						  QString("Exif-Rename") + tr("Abort Renaming"),
						  tr("Should the current operation really be cancelled?"));

		if (closing == QMessageBox::No) { event->ignore(); }
		else
		{
			emit windowClosing();
			event->accept();
		}
	}
}

void ProgressWindow::showError(QString err)
{
	QMessageBox::critical(nullptr, QString("Exif-Rename: ") +tr("Error"), err);
}

void ProgressWindow::showFinish(QString logFile)
{
	finish = true;
	QMessageBox::StandardButton reply = QMessageBox::question(
											this,
											QString("Exif-Rename: ") + tr("Renaming completed"),
											tr("The renaming is completed.\n"
											   "Would you now like to check the log file for possible errors?"),
											QMessageBox::Yes | QMessageBox::No);

	if(reply == QMessageBox::StandardButton::Yes)
	{

        ExtendedLog::TextLogReader *logReader = new ExtendedLog::TextLogReader(logFile);
		ExtendedLogViewer::ExtendedLogViewer *logViewer = new ExtendedLogViewer::ExtendedLogViewer(
															  logReader,
                                                              this->windowIcon(),
															  "Exif-Rename");
		logViewer->setAttribute(Qt::WA_DeleteOnClose);
		logViewer->show();
	}
    close();
}

void ProgressWindow::showProgress(int percentage, QStringList state)
{
	ui->progressBar->setValue(percentage);
	ui->lblFileNr->setText(state.at(0));
	ui->lblMaxFileNumber->setText(state.at(1));
	ui->lblCurrentFile->setText(state.at(2));
}
